This is for SDP18 NUS ISE Metaheuristic Surgery Scheduling. It has 4 heuristics to choose from, Tabu Search, Genetic Algorithm, Simulated Annealing and Hill climbing. 
The main functions for the heuristics are schedule_GA, schedule_SA, schedule_TS, schedule_HCO
It will prompt you to select 3 files, they have to be in a specific format for the code to work. 